@@ -10,7 +10,7 @@ class ElastalertWebhook(WebhookBase):
         try:
             # Default parameters
             print("payload: "+str(payload))
-            rawData = str(payload)
+            rawData = "data="+str(payload)
             resource = payload.get('queryKey','N/A')
             environment = payload.get('fedUniqueName','N/A')
             res = payload.get('event','N/A')
@@ -50,6 +50,7 @@ class ElastalertWebhook(WebhookBase):
             createTime = createTime,
             attributes = attributes,
             environment = environment,
+            type = "ElastAlertNotification",
             rawData = rawData
         #     environment=payload.get('environment', environment),
         #     severity=payload.get('severity', severity),
